// Copyright (c) 2019-2020 NetEase, Inc. All right reserved.

part of nertc;

class _StatsEventHandler with _EventHandler {
  NERtcStatsEventCallback? _callback;

  _StatsEventHandler();

  void setCallback(NERtcStatsEventCallback? callback) {
    this._callback = callback;
  }

  void _handleOnRtcStats(Map<dynamic, dynamic> arguments) {
    _callback!.onRtcStats(NERtcStats.fromMap(arguments));
  }

  void _handleOnLocalAudioStats(Map<dynamic, dynamic> arguments) {
    _callback!.onLocalAudioStats(NERtcAudioSendStats.fromMap(arguments));
  }

  void _handleOnRemoteAudioStats(Map<dynamic, dynamic> arguments) {
    List<dynamic> argumentList = arguments['list'];
    List<NERtcAudioRecvStats> statsList = <NERtcAudioRecvStats>[];
    for (Map<dynamic, dynamic> argument in argumentList as Iterable<Map<dynamic, dynamic>>) {
      statsList.add(NERtcAudioRecvStats.fromMap(argument));
    }
    _callback!.onRemoteAudioStats(statsList);
  }

  void _handleOnLocalVideoStats(Map<dynamic, dynamic> arguments) {
    _callback!.onLocalVideoStats(NERtcVideoSendStats.fromMap(arguments));
  }

  void _handleOnRemoteVideoStats(Map<dynamic, dynamic> arguments) {
    List<dynamic> argumentList = arguments['list'];
    var statsList = <NERtcVideoRecvStats>[];
    for (Map<dynamic, dynamic> argument in argumentList as Iterable<Map<dynamic, dynamic>>) {
      statsList.add(NERtcVideoRecvStats.fromMap(argument));
    }
    _callback!.onRemoteVideoStats(statsList);
  }

  void _handleOnNetworkQuality(Map<dynamic, dynamic> arguments) {
    List<dynamic> argumentList = arguments['list'];
    var statsList = <NERtcNetworkQualityInfo>[];
    for (Map<dynamic, dynamic> argument in argumentList as Iterable<Map<dynamic, dynamic>>) {
      statsList.add(NERtcNetworkQualityInfo.fromMap(argument));
    }
    _callback!.onNetworkQuality(statsList);
  }

  @override
  bool handler(String method, Map<dynamic, dynamic> arguments) {
    if (_callback == null) return false;
    switch (method) {
      case 'onRtcStats':
        _handleOnRtcStats(arguments);
        return true;
      case 'onLocalAudioStats':
        _handleOnLocalAudioStats(arguments);
        return true;
      case 'onRemoteAudioStats':
        _handleOnRemoteAudioStats(arguments);
        return true;
      case 'onLocalVideoStats':
        _handleOnLocalVideoStats(arguments);
        return true;
      case 'onRemoteVideoStats':
        _handleOnRemoteVideoStats(arguments);
        return true;
      case 'onNetworkQuality':
        _handleOnNetworkQuality(arguments);
        return true;
      default:
        return false;
    }
  }
}
